#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: simple-sendfile
version: 0.2.22
id: simple-sendfile-0.2.22-5543b22c4382748239d6fed42d7bf1f0
key: simpl_4VYduwsMhnIC5qGgDYCFZo
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.Sendfile System.Linux.Sendfile
hidden-modules: Network.Sendfile.Types Network.Sendfile.Linux
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/simple-sendfile-0.2.22
library-dirs: /usr/lib/ghc-7.10.3/site-local/simple-sendfile-0.2.22
data-dir: /usr/share/arm-linux-ghc-7.10.3/simple-sendfile-0.2.22
hs-libraries: HSsimple-sendfile-0.2.22-4VYduwsMhnIC5qGgDYCFZo
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
haddock-interfaces: /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock
haddock-html: /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
